#! /usr/bin/python
# -*- coding: utf-8 -*-

#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
#
"""Commandes pour les listes.
Auteur: Pierre-Alexandre Fournie
Date: 07-11-2023
"""

# A.B.
# note: 8/10
# Voir remarques


######################################
# Algorithme 0:                      #
# Exemple de commandes               #
######################################

from math import*
l1 = ["toto",4,[2,3],3.14]      # declaration de liste
len(l1)                         # longueur de liste
l1[0]                           # element de l1 d'indice 0
l1[1]                           # element de l1 d'indice 1
l1[2]                           # element de l1 d'indice 2: c'est une liste
l1[len(l1)-1]                   # dernier element de l1
l1+[-1 ,0]                      # concatenation de l1 et de la liste [-1,0]
3*[2 ,3 ,4]                     # repetition de liste
l1.append(42)                   # ajout d'un element a la fin de l1
l1.extend([ -1 ,0])             # ajout de plusieurs elements a la fin de l1
del(l1[6])                      # suppression de l'element d'indice 6 dans l1
l1.remove('toto')               # suppression des elements "toto" dans l1
l1.insert(4,"titi")             # insertion de "titi" en indice 4 dans l1
list(range(5))                  # liste contenant les entiers de [[0;4]]]
list(range(3 ,7))               # liste contenant les entiers de [[3;6]]]
list(range(3,11,2))             # liste contenant les entiers de [[3;10]]] avec un pas de 2
l1[0:5]                         # liste contenant les elements de l1 d'indices dans l'intervalle [[0;5]]
l1[0:5:2]                       # liste contenant les elements de l1 d'indices dans l'intervalle [[0;5]] avec un pas de 2
l1[:5]                          # liste contenant tous les elements de l1 jusqu'a l'element d'indice 5
l1[4:]                          # liste contenant tous les elements de l1 a partir de l'element d'indice 4
l1[:]                           # liste contenant tous les elements de l1
l1[::2]                         # liste contenant tous les elements de l1 d'indice pair
l1[3]="tutu"                    # remplacement de l'element d'indice 3 de l1 par "tutu"
"toto" in l1                    # "toto" est-il dans l1?
3.14 in l1                      # 3.14 est-il dans l1?
l1.index(3.14)                  # recherche du premier indice de l'element 3.14
max([1,3,-1])                   # renvoie le maximum de la liste [1,3,-1]
sum([1,3,-1])                   # renvoie la somme des Ã©lÃ©ments de la liste [1,3,-1]


######################################
# Algorithme 1:                      #
# Faire une copie de liste           #
######################################
l2=l1[:]                        #Cette commande permet de créer l2 tout en créeant un nouvel emplacement de mémoire ainsi si L1 et modifié L2 ne sera pas modifié
#l2=l1                           #Cette commande crée l2 mais uniquement selon l1 donc si l1 est modifié l2 le sera aussi donc elle possède le défaut
l2.remove("tutu")               #Cette commande nous permets d'enlever "tutu" de l2 et ainsi de voir selon la commande si un emplacement mémoier a été crée ou non

######################################
# Algorithme 2:                      #
# Creation de liste par fonction     #
######################################

l3=[i**2 for i in range(5)]
l4=[i**2 for i in range(1,6,2)]
l5=[(x,y) for x in range(1,7) for y in range(1,7) if x!=y]
l6=[1/i for i in range(2,50) if i%2==0]
l7=[(x,y) for x in range(1,100) for y in range(1,100) if (x*y)%4==0]            #cette commande génère toues les combinaisons de couple possible ou x et y sont compris entre 1 et 100 et le produit est un multiple de 4. | if (x *y)%4 on vérfie si le produit de x et y est un multiple de 4 grâce au %


######################################
# Algorithme 3:                      #
# Fonction ProduitScalaire           #
######################################
A=[2,3]
B=[4,5]
def ProduitScalaire(A,B):
    return A[0]*B[0]+A[1]*B[1]

######################################
# Algorithme 4:                      #
# Fonction Norme                     #
######################################


A=[2,3]
# un seul argument pour norme!
def Norme(A,B):
    return(sqrt(A[0]^2+A[1]^2))

######################################
# Algorithme 5:                      #
# Fonction Determinant               #
######################################

A=[2,3]
B=[4,5]
def Determinant(A,B):
    return (A[0]*B[1]-B[0]*A[1])


######################################
# Algorithme 6:                      #
# Fonction  SontColineaires          #
######################################

def Sontcolinaires (A,B):
    return Determinant(A,B) == 0    #prend directement la valeur de la fonction determinant et si elle est égale à 0 alors "true" sinon "false"

######################################
# Algorithme 7:                      #
# Fonction Pol2Cart                  #
######################################

r=[2]
t=[5]
# en general, on donne t en radian directement.
def Pol2Cart (r,t):
    x = r[0]*cos(t[0]*pi/180)       #t = theta ; r = rho. t * pi/180 = conversion degrés en radian
    y = r[0]*sin(t[0]*pi/180)

    return (x,y)

######################################
# Algorithme 8:                      #
# Fonction Cart2Pol                  #
######################################

x=[2]
y=[5]
def Cart2Pol(x,y):
    r = sqrt(x[0]**2+y[0]**2)
    t = atan(y[0]/x[0]) # faire une disjonction. atan n'est pas toujours adaptee (cas x=0 notamment).

    return (r,t)

######################################
# Algorithme 9:                      #
# Fonction EqDroiteOrth              #
######################################
A=[1,2]
n=[2,1]
def EqDroiteOrth(A,n):
    A[0], A[1] = A # inutile
    a, b = n
    c = n[0] * A[0] + n[1] * A[1]
    return [a, b, c]

######################################
# Algorithme 10:                     #
# Fonction EqDroiteCol               #
######################################

A=[4,7]
d=[3,9]
def EqDroiteCol(A,d):
    x_A, y_A = A
    u, v = d
    a = -v
    b = u
    c = a * x_A + b * y_A
    return [a, b, c]



######################################
# Algorithme 11:                     #
# Fonction Barycentre                #
######################################

S1 = [[[0,0],1],[[4,4],1]]
S2 = [[[0,0],1],[[4,4],1],[[-2,2],2]]

######################################
# Algorithme 12:                     #
# Algorithme bonus                   #
######################################
