#! /usr/bin/python
# -*- coding: utf-8 -*-

#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
#
"""Commandes pour les listes.
Auteur: Pierre-Alexandre Fournie
Date: 07-11-2023
"""

# Copie trop proche de Hugues et Louna
# Note: 4/10
# Voir les remarques plus bas.


######################################
# Algorithme 0:                      #
# Exemple de commandes               #
######################################


l1 = ["toto",4,[2,3],3.14]      # declaration de liste
len(l1)                         # longueur de liste
l1[0]                           # element de l1 d'indice 0
l1[1]                           # element de l1 d'indice 1
l1[2]                           # element de l1 d'indice 2: c'est une liste
l1[len(l1)-1]                   # dernier element de l1
l1+[-1 ,0]                      # concatenation de l1 et de la liste [-1,0]
3*[2 ,3 ,4]                     # repetition de liste
l1.append(42)                   # ajout d'un element a la fin de l1
l1.extend([ -1 ,0])             # ajout de plusieurs elements a la fin de l1
del(l1[6])                      # suppression de l'element d'indice 6 dans l1
l1.remove('toto')               # suppression des elements "toto" dans l1
l1.insert(4,"titi")             # insertion de "titi" en indice 4 dans l1
list(range(5))                  # liste contenant les entiers de [[0;4]]]
list(range(3 ,7))               # liste contenant les entiers de [[3;6]]]
list(range(3,11,2))             # liste contenant les entiers de [[3;10]]] avec un pas de 2
l1[0:5]                         # liste contenant les elements de l1 d'indices dans l'intervalle [[0;5]]
l1[0:5:2]                       # liste contenant les elements de l1 d'indices dans l'intervalle [[0;5]] avec un pas de 2
l1[:5]                          # liste contenant tous les elements de l1 jusqu'a l'element d'indice 5
l1[4:]                          # liste contenant tous les elements de l1 a partir de l'element d'indice 4
l1[:]                           # liste contenant tous les elements de l1
l1[::2]                         # liste contenant tous les elements de l1 d'indice pair
l1[3]="tutu"                    # remplacement de l'element d'indice 3 de l1 par "tutu"
"toto" in l1                    # "toto" est-il dans l1?
3.14 in l1                      # 3.14 est-il dans l1?
l1.index(3.14)                  # recherche du premier indice de l'element 3.14
max([1,3,-1])                   # renvoie le maximum de la liste [1,3,-1]
sum([1,3,-1])                   # renvoie la somme des Ã©lÃ©ments de la liste [1,3,-1]

######################################
# Algorithme 1:                      #
# Faire une copie de liste           #
######################################

l2=l1[:]                        # Cette fonctionnalité permet de modifier les éléments de l2 et pas ceux de l1. Ex : l2.remove('titi'), supprime titi seulement de l2.
l2=l1                           # Cette fonctionnalité possède un défaut en modifiant l2 elle modifie aussi l1. Ex : l2.remove('titi'), supprime titi de l1 et l2. Cela est dû au fait que nous avons mis que l2=l1 et non l2=aux elements de l1[:]
l2.remove('titi') 

# TB

######################################
# Algorithme 2:                      #
# Creation de liste par fonction     #
######################################

l3=[i**2 for i in range(5)]
l4=[i**2 for i in range(1,6,2)]
l5=[(x,y) for x in range(1,7) for y in range(1,7) if x!=y]
l6=[1/i for i in range(2,50) if i%2==0]
l7=[(x,y) for x in range(1,100) for y in range (1,100) if (x*y)%4==0]


######################################
# Algorithme 3:                      #
# Fonction ProduitScalaire           #
######################################

A=[4,2]
B=[3,3]
def ProduitScalaire (A,B):
    return A[0]*B[0]+A[1]*B[1]


######################################
# Algorithme 4:                      #
# Fonction Norme                     #
######################################
from math import*
A=[4,2]
B=[3,3]
def Norme1 (A):
    return sqrt(A[0]**2+A[1]**2)
def Norme2 (B) : # inutile, vous avez deja defini cette fonction.
    return sqrt(B[0]**2+B[1]**2)

######################################
# Algorithme 5:                      #
# Fonction Determinant               #
######################################

A=[4,2]
B=[3,3]
def Determinant (A,B):
    return (A[0]*B[1]-B[0]*A[1])


######################################
# Algorithme 6:                      #
# Fonction  SontColineaires          #
######################################

A=[4,2]
B=[3,3]
def SontColineaires (A,B):
    return Determinant(A,B)==0

######################################
# Algorithme 7:                      #
# Fonction Pol2Cart                  #
######################################
x=0
y=0
A=[4,2]
B=[3,3]
def Pol12cart(A,B):
    x=A[0]*cos(A[1])
    y=A[0]*sin(A[1])
    return(x,y)

######################################
# Algorithme 8:                      #
# Fonction Cart2Pol                  #
######################################

x=0
y=0
A=[4,2]
B=[3,3]
def Cart2pol(A,B):
    x=sqrt((A[0]**2)+(A[1]**2))
    y=arctan(A[1]/A[0]) # Pas toujours adapte. Il faut faire une disjonction de cas!
    return(x,y)

######################################
# Algorithme 9:                      #
# Fonction EqDroiteOrth              #
######################################



######################################
# Algorithme 10:                     #
# Fonction EqDroiteCol               #
######################################



######################################
# Algorithme 11:                     #
# Fonction Barycentre                #
######################################

S1 = [[[0,0],1],[[4,4],1]]
S2 = [[[0,0],1],[[4,4],1],[[-2,2],2]]

######################################
# Algorithme 12:                     #
# Algorithme bonus                   #
######################################
