#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
#
"""Commandes pour les listes.
Auteur: Pierre-Alexandre Fournie
Date: 07-11-2023
"""

# Tres bon travail! 
# Note: 9/10
# Quelques erreurs, voir les remarques dans le script.



######################################
# Algorithme 0:                      #
# Exemple de commandes               #
######################################


l1 = ["toto",4,[2,3],3.14]      # declaration de liste
len(l1)                         # longueur de liste
l1[0]                           # element de l1 d'indice 0
l1[1]                           # element de l1 d'indice 1
l1[2]                           # element de l1 d'indice 2: c'est une liste
l1[len(l1)-1]                   # dernier element de l1
l1+[-1 ,0]                      # concatenation de l1 et de la liste [-1,0]
3*[2 ,3 ,4]                     # repetition de liste
l1.append(42)                   # ajout d'un element a la fin de l1
l1.extend([ -1 ,0])             # ajout de plusieurs elements a la fin de l1
del(l1[6])                      # suppression de l'element d'indice 6 dans l1
l1.remove('toto')               # suppression des elements "toto" dans l1
l1.insert(4,"titi")             # insertion de "titi" en indice 4 dans l1
list(range(5))                  # liste contenant les entiers de [[0;4]]]
list(range(3 ,7))               # liste contenant les entiers de [[3;6]]]
list(range(3,11,2))             # liste contenant les entiers de [[3;10]]] avec un pas de 2
l1[0:5]                         # liste contenant les elements de l1 d'indices dans l'intervalle [[0;5]]
l1[0:5:2]                       # liste contenant les elements de l1 d'indices dans l'intervalle [[0;5]] avec un pas de 2
l1[:5]                          # liste contenant tous les elements de l1 jusqu'a l'element d'indice 5
l1[4:]                          # liste contenant tous les elements de l1 a partir de l'element d'indice 4
l1[:]                           # liste contenant tous les elements de l1
l1[::2]                         # liste contenant tous les elements de l1 d'indice pair
l1[3]="tutu"                    # remplacement de l'element d'indice 3 de l1 par "tutu"
"toto" in l1                    # "toto" est-il dans l1?
3.14 in l1                      # 3.14 est-il dans l1?
l1.index(3.14)                  # recherche du premier indice de l'element 3.14
max([1,3,-1])                   # renvoie le maximum de la liste [1,3,-1]
sum([1,3,-1])                   # renvoie la somme des éléments de la liste [1,3,-1]

######################################
# Algorithme 1:                      #
# Faire une copie de liste           #

######################################

# Copie effectivement les valeurs de l1
l2=l1[:]
# Ne crée qu'une nouvelle référence à un l1 et
# non pas une nouvelle liste
l2=l1

######################################
# Algorithme 2:                      #
# Creation de liste par fonction     #
######################################

l3=[i**2 for i in range(5)]
l4=[i**2 for i in range(1,6,2)]
l5=[(x,y) for x in range(1,7) for y in range(1,7) if x!=y]

# range(2, 51, 2) itérateur sur l'intervalle
# [2; 50] des entiers avec un pas de 2 (2 en 2)
l6 = [i for i in range(2, 51, 2)] # attention lisez mieux l enonce! On veut determiner les inverses.

# Avec la syntaxe de compréhension de listes
# nous créeons deux boucles imbriquées, de x sur [1; 100]
# et de y sur [1; 100] et dont le couple (x; y) n'est que
# ajouté sur la liste si le reste de la division euclidienne
# de x * y par 4 est égal à 0
l7 = [(x, y) for x in range(1, 101) for y in range(1, 101) if (x*y) % 4 == 0 ]



######################################
# Algorithme 3:                      #
# Fonction ProduitScalaire           #
######################################

def ProduitScalaire(vec_a, vec_b):
    return vec_a[0] * vec_b[0] + vec_a[1] * vec_b[1]

from math import sqrt, cos, sin, atan, pi

######################################
# ALGORITHME 4                       #
# Fonction Norme                     #
######################################

def Norme(vec):
    return sqrt(vec[0]**2 + vec[1]**2)

######################################
# Algorithme 5:                      #
# Fonction Determinant               #
######################################

def Determinant(vec_a, vec_b):
    return vec_a[0] * vec_b[1] - vec_a[1] * vec_b[0]


######################################
# Algorithme 6:                      #
# Fonction  SontColineaires          #
######################################

def SontColineaires(a, b):
    return Determinant(vec_a, vec_b) == 0

######################################
# Algorithme 7:                      #
# Fonction Pol2Cart                  #
######################################

def Pol2Cart(rho, theta):
    return [rho * cos(theta), rho * sin(theta)]

######################################
# Algorithme 8:                      #
# Fonction Cart2Pol                  #
######################################

def Cart2Pol(x, y):
    rho = sqrt(x**2 + y**2)
    if x > 0 or x < 0:
        return [rho, atan(y/x)]  # attention pour x<0, il faut ajouter pi a atan.
    if y > 0:
        return [rho, pi/2]
    return [rho, -pi/2]

######################################
# Algorithme 9:                      #
# Fonction EqDroiteOrth              #
######################################

def EqDroiteOrth(A, n):
    a = n[0]
    b = - n[1] # erreur!
    c = n[1] * A[0] - n[0] * A[1]  # erreur!
    return [a, b, c]

######################################
# Algorithme 10:                     #
# Fonction EqDroiteCol               #
######################################

def EqDroiteCol(A, n):
    return EqDroiteOrth(A, [-n[1], n[0]]) # bonne idee.

######################################
# Algorithme 11:                     #
# Fonction Barycentre                #
######################################

S1 = [[[0,0],1],[[4,4],1]]
S2 = [[[0,0],1],[[4,4],1],[[-2,2],2]]

def Barycentre(points: list):
    x = 0
    y = 0
    coeff = 0

    for point, poids in points:
        x += poids* point[0]
        y += poids* point[1]
        coeff += poids
    return [x / coeff , y / coeff]
    if coeff == 0: # a placer avant, sinon erreur!
        raise Exception("La somme des poids ne peut être égale à 0")

print(Barycentre(S1), Barycentre(S2))

######################################
# Algorithme 12:                     #
# Algorithme bonus                   #
######################################

a = len([(x, y) for x in range(-101, 101) for y in range(-101, 101) if sqrt(x ** 2 + y ** 2) <= 100])
print(a)
# TB!
