#! /usr/bin/python
# -*- coding: utf-8 -*-

#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
#
"""Commandes pour les listes.
Auteur: Pierre-Alexandre Fournie
Date: 07-11-2023
"""

# Bon travail.
# Note: 8/10 
# Voir les remarques plus bas.


######################################
# Algorithme 0:                      #
# Exemple de commandes               #
######################################

from math import*


l1 = ["toto",4,[2,3],3.14]      # declaration de liste
len(l1)                         # longueur de liste
l1[0]                           # element de l1 d'indice 0
l1[1]                           # element de l1 d'indice 1
l1[2]                           # element de l1 d'indice 2: c'est une liste
l1[len(l1)-1]                   # dernier element de l1
l1+[-1 ,0]                      # concatenation de l1 et de la liste [-1,0]
3*[2 ,3 ,4]                     # repetition de liste
l1.append(42)                   # ajout d'un element a la fin de l1
l1.extend([ -1 ,0])             # ajout de plusieurs elements a la fin de l1
del(l1[6])                      # suppression de l'element d'indice 6 dans l1
l1.remove('toto')               # suppression des elements "toto" dans l1
l1.insert(4,"titi")             # insertion de "titi" en indice 4 dans l1
list(range(5))                  # liste contenant les entiers de [[0;4]]]
list(range(3 ,7))               # liste contenant les entiers de [[3;6]]]
list(range(3,11,2))             # liste contenant les entiers de [[3;10]]] avec un pas de 2
l1[0:5]                         # liste contenant les elements de l1 d'indices dans l'intervalle [[0;5]]
l1[0:5:2]                       # liste contenant les elements de l1 d'indices dans l'intervalle [[0;5]] avec un pas de 2
l1[:5]                          # liste contenant tous les elements de l1 jusqu'a l'element d'indice 5
l1[4:]                          # liste contenant tous les elements de l1 a partir de l'element d'indice 4
l1[:]                           # liste contenant tous les elements de l1
l1[::2]                         # liste contenant tous les elements de l1 d'indice pair
l1[3]="tutu"                    # remplacement de l'element d'indice 3 de l1 par "tutu"
"toto" in l1                    # "toto" est-il dans l1?
3.14 in l1                      # 3.14 est-il dans l1?
l1.index(3.14)                  # recherche du premier indice de l'element 3.14
max([1,3,-1])                   # renvoie le maximum de la liste [1,3,-1]
sum([1,3,-1])                   # renvoie la somme des éléments de la liste [1,3,-1]

######################################
# Algorithme 1:                      #
# Faire une copie de liste           #
######################################

l2=l1[:] # dans la console on tape une des deux commande, puis on peut modifier une des lsites en ajoutant un élement l1.append("test"), si l'algorithm crée un espace memoire alors en tapant l1 puis L2 on aura 2 listes differentes#
#l2=l1 dans ce cas la deuxiéme commande ne rajoute pas d'espace mémoire

######################################
# Algorithme 2:                      #
# Creation de liste par fonction     #
######################################

l3=[i**2 for i in range(5)]
l4=[i**2 for i in range(1,6,2)]
l5=[(x,y) for x in range(1,7) for y in range(1,7) if x!=y]
l6=[1/i for i in range(2,51,2)] #liste qui crée l'inverse des nombres paires de l'intervale [(2,50)] TB
l7=[(x,y) for x in range(1,101) for y in range(1,101) if x*y%4==0 ] #liste qui crée les couples (x,y) appartenant à (1,100) et donc le produit de x et y est multiple de 4

######################################
# Algorithme 3:                      #
# Fonction ProduitScalaire           #
######################################

def ProduitScalaire(x,y):
    x1=x[0]*y[0]
    y1=x[1]*y[1]
    return(x1+y1)

######################################
# Algorithme 4:                      #
# Fonction Norme                     #
######################################

def Norme(x):
    m=x[0]**2
    n=x[1]**2
    return(sqrt(m+n))

######################################
# Algorithme 5:                      #
# Fonction Determinant               #
######################################

def Determinant(x,y):
    x1=x[0]*y[1]
    y1=x[1]*y[0]
    #print ("inside Determinant")
    return(x1-y1)

######################################
# Algorithme 6:                      #
# Fonction  SontColineaires          #
######################################


# faites un return sur un booleen plutot qu'un print.
def Sontcolineaires(x,y):
    if Determinant(x,y)==0:
        print("vrai")
    else:
        print("Faux")

######################################
# Algorithme 7:                      #
# Fonction Pol2Cart                  #
######################################

def Pol2Cart(w):
    x=w[0]*cos(w[1])
    y=w[0]*sin(w[1])
    return(x,y)

######################################
# Algorithme 8:                      #
# Fonction Cart2Pol                  #
######################################

def Cart2pol(a):
    x=sqrt(a[0]**2+a[1]**2)
    y=atan(a[1]/a[0]) # attention, atan n'est pas toujours adapte.
    return(x,y)
######################################
# Algorithme 9:                      #
# Fonction EqDroiteOrth              #
######################################

def EqDroiteOrth (x,y):
    a=y[0]
    b=y[1]
    c=a*x[0]+b*x[1]
    return(a,b,c)

######################################
# Algorithme 10:                     #
# Fonction EqDroiteCol               #
######################################



######################################
# Algorithme 11:                     #
# Fonction Barycentre                #
######################################

S1 = [[[0,0],1],[[4,4],1]]
S2 = [[[0,0],1],[[4,4],1],[[-2,2],2]]

######################################
# Algorithme 12:                     #
# Algorithme bonus                   #
######################################



#Main - Programme Principal
#print ("HelloWorld")
#Sontcolineaires([2,2], [26,24])
#print(ProduitScalaire([3,8],[4,6]))
#print(Pol2Cart([2,pi/4]))
#print(Cart2pol([sqrt(2),sqrt(2)]))
#print(EqDroiteOrth([1,1],[1,1]))
