#! /usr/bin/python
# -*- coding: utf-8 -*-

#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
#
"""Commandes pour les listes.
Auteur: Pierre-Alexandre Fournie
Date: 07-11-2023
"""
# NOTE: 8
# Attention, eviter les caracteres speciaux!


######################################
# Algorithme 0:                      #
# Exemple de commandes               #
######################################


l1 = ["toto",4,[2,3],3.14]      # declaration de liste
len(l1)                         # longueur de liste
l1[0]                           # element de l1 d'indice 0
l1[1]                           # element de l1 d'indice 1
l1[2]                           # element de l1 d'indice 2: c'est une liste
l1[len(l1)-1]                   # dernier element de l1
l1+[-1 ,0]                      # concatenation de l1 et de la liste [-1,0]
3*[2 ,3 ,4]                     # repetition de liste
l1.append(42)                   # ajout d'un element a la fin de l1
l1.extend([ -1 ,0])             # ajout de plusieurs elements a la fin de l1
del(l1[6])                      # suppression de l'element d'indice 6 dans l1
l1.remove('toto')               # suppression des elements "toto" dans l1
l1.insert(4,"titi")             # insertion de "titi" en indice 4 dans l1
list(range(5))                  # liste contenant les entiers de [[0;4]]]
list(range(3 ,7))               # liste contenant les entiers de [[3;6]]]
list(range(3,11,2))             # liste contenant les entiers de [[3;10]]] avec un pas de 2
l1[0:5]                         # liste contenant les elements de l1 d'indices dans l'intervalle [[0;5]]
l1[0:5:2]                       # liste contenant les elements de l1 d'indices dans l'intervalle [[0;5]] avec un pas de 2
l1[:5]                          # liste contenant tous les elements de l1 jusqu'a l'element d'indice 5
l1[4:]                          # liste contenant tous les elements de l1 a partir de l'element d'indice 4
l1[:]                           # liste contenant tous les elements de l1
l1[::2]                         # liste contenant tous les elements de l1 d'indice pair
l1[3]="tutu"                    # remplacement de l'element d'indice 3 de l1 par "tutu"
"toto" in l1                    # "toto" est-il dans l1?
3.14 in l1                      # 3.14 est-il dans l1?
l1.index(3.14)                  # recherche du premier indice de l'element 3.14
max([1,3,-1])                   # renvoie le maximum de la liste [1,3,-1]
sum([1,3,-1])                   # renvoie la somme des éléments de la liste [1,3,-1]

######################################
# Algorithme 1:                      #
# Faire une copie de liste           #
######################################

l2=l1[:]
# l2=l1: cette commande est defectueuse

######################################
# Algorithme 2:                      #
# Creation de liste par fonction     #
######################################

l3=[i**2 for i in range(5)]
l4=[i**2 for i in range(1,6,2)]
l5=[(x,y) for x in range(1,7) for y in range(1,7) if x!=y]
l6=[i**-1 for i in range(2,51) if i%2==0 ]
l7=[(x,y) for x in range(1,101) for y in range(1,101) if (x*y)%4 == 0]

######################################
# Algorithme 3:                      #
# Fonction ProduitScalaire           #
######################################

A=[1,2]
B=[2,1]
def ProduitScalaire(A,B):
    return (A[0]*B[0])+(A[1]*B[1])

ProduitScalaire(A,B)

######################################
# Algorithme 4:                      #
# Fonction Norme                     #
######################################

from math import *
C=[2,2]
def Norme(u):
    return sqrt(u[0]**2+u[1]**2)

Norme(C)

######################################
# Algorithme 5:                      #
# Fonction Determinant               #
######################################

def determinant(u,v):
    return (u[0]*v[1])-(u[1]*v[0])

######################################
# Algorithme 6:                      #
# Fonction  SontColineaires          #
######################################

def SontColineaires(u,v):
    return determinant(u,v)==0

######################################
# Algorithme 7:                      #
# Fonction Pol2Cart                  #
######################################

from math import *
def Pol2Cart(pol):
    pol=[ρ,θ]
    x=pol[0]*cos(pol[1])
    y=pol[0]*sin(θpol[1]) # erreur
    return (x,y)

######################################
# Algorithme 8:                      #
# Fonction Cart2Pol                  #
######################################

from math import *
def Cart2Pol(cart):
    cart=[x,y]
    ρ=sqrt(cart[0]**2+cart[1]**2)
    θ=atan2(y/x) # faire une disjonction!
    return (ρ,θ)


######################################
# Algorithme 9:                      #
# Fonction EqDroiteOrth              #
######################################

def EqDroiteOrth(A,n):
    A=[x,y]
    n=[a,b]
    c=n[0]*A[0]+n[1]*A[1]
    return (a,b,c)

######################################
# Algorithme 10:                     #
# Fonction EqDroiteCol               #
######################################

def EqDroiteCol(A,u):
    A=[x,y]
    u=[-b,a]
    c=u[1]*A[0]+u[0]*A[1]
    return (a,b,c)

######################################
# Algorithme 11:                     #
# Fonction Barycentre                #
######################################

def Barycentre(S1):
    A=[x,y,α]
    B=[x1,y1,β]
    G=((A[0]*A[2]+B[0]*B[2])/A[2]+B[2],(A[1]*A[2]+B[1]*B[2])/A[2]+B[2])
    return G

def Barycentre(S2):
    A=[x,y,α]
    B=[x1,y1,β]
    C=[x2,y2,γ]
    # attention, cela doit fonctionner quelle que soit la taille du systeme de points ponderes!
    G=((A[0]*A[2]+B[0]*B[2]+C[0]*C[2])/A[2]+B[2]+C[2],(A[1]*A[2]+B[1]*B[2]+C[0]*C[2])/A[2]+B[2]+C[2])
    return G

S1 = [[[0,0],1],[[4,4],1]]
S2 = [[[0,0],1],[[4,4],1],[[-2,2],2]]

######################################
# Algorithme 12:                     #
# Algorithme bonus                   #
######################################


