#! /usr/bin/python
# -*- coding: utf-8 -*-

#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
#
"""Commandes pour les listes.
Auteur: Pierre-Alexandre Fournie
Date: 07-11-2023
"""


######################################
# Algorithme 0:                      #
# Exemple de commandes               #
######################################


l1 = ["toto",4,[2,3],3.14]      # declaration de liste
len(l1)                         # longueur de liste
l1[0]                           # element de l1 d'indice 0
l1[1]                           # element de l1 d'indice 1
l1[2]                           # element de l1 d'indice 2: c'est une liste
l1[len(l1)-1]                   # dernier element de l1
l1+[-1 ,0]                      # concatenation de l1 et de la liste [-1,0]
3*[2 ,3 ,4]                     # repetition de liste
l1.append(42)                   # ajout d'un element a la fin de l1
l1.extend([ -1 ,0])             # ajout de plusieurs elements a la fin de l1
del(l1[6])                      # suppression de l'element d'indice 6 dans l1
l1.remove('toto')               # suppression des elements "toto" dans l1
l1.insert(4,"titi")             # insertion de "titi" en indice 4 dans l1
list(range(5))                  # liste contenant les entiers de [[0;4]]]
list(range(3 ,7))               # liste contenant les entiers de [[3;6]]]
list(range(-11,11,2))           # liste contenant les entiers de [[-11;10]]] avec un pas de 2
l1[0:5]                         # liste contenant les elements de l1 d'indices dans l'intervalle [[0;5]]
l1[0:5:2]                       # liste contenant les elements de l1 d'indices dans l'intervalle [[0;5]] avec un pas de 2
l1[:5]                          # liste contenant tous les elements de l1 jusqu'a l'element d'indice 5
l1[4:]                          # liste contenant tous les elements de l1 a partir de l'element d'indice 4
l1[:]                           # liste contenant tous les elements de l1
l1[::2]                         # liste contenant tous les elements de l1 d'indice pair
l1[3]="tutu"                    # remplacement de l'element d'indice 3 de l1 par "tutu"
"toto" in l1                    # "toto" est-il dans l1?
3.14 in l1                      # 3.14 est-il dans l1?
l1.index(3.14)                  # recherche du premier indice de l'element 3.14
max([1,3,-1])                   # renvoie le maximum de la liste [1,3,-1]
sum([1,3,-1])                   # renvoie la somme des éléments de la liste [1,3,-1]


######################################
# Algorithme 1:                      #
# Faire une copie de liste           #
######################################

l2=l1[:]
# l2=l1

######################################
# Algorithme 2:                      #
# Creation de liste par fonction     #
######################################

l3=[i**2 for i in range(5)]
l4=[i**2 for i in range(1,6,2)]
l5=[(x,y) for x in range(1,7) for y in range(1,7) if x!=y]
l6=list(range(2,51,2))
l7=[(i,j) for i in range(1,101) for j in range(1,101) if (i*j)%4==0]

######################################
# Algorithme 3:                      #
# Fonction ProduitScalaire           #
######################################

def ProduitScalaire(u,v):
    return u[0]*v[0]+u[1]*v[1]

######################################
# Algorithme 4:                      #
# Fonction Norme                     #
######################################

def Norm(u):
    return ProduitScalaire(u,u)**0.5 # on peut exploiter les fonctions deja ecrites

######################################
# Algorithme 5:                      #
# Fonction Determinant               #
######################################

def Determinant(u,v):
    return u[0]*v[1]-u[1]*v[0]

######################################
# Algorithme 6:                      #
# Fonction  SontColineaires          #
######################################

def SontColineaires(u,v):
    return Determinant(u,v)==0

######################################
# Algorithme 7:                      #
# Fonction Pol2Cart                  #
######################################

from math import * # on importe les fonctions du module math
def Pol2Cart(pol): # pol[0] c'est rho et pol[1] c'est theta.
    return [pol[0]*cos(pol[1]),pol[0]*sin(pol[1])]

######################################
# Algorithme 8:                      #
# Fonction Cart2Pol                  #
######################################

def Cart2Pol(cart): # cart[0] c'est x et cart[1] c'est y.
    rho = Norm(cart)
    if rho==0: # on traite le cas de l'origine separement
        return [0,0]
    elif cart[0]==0: # on traite le cas ou theta=+- pi/2 separement
        if cart[1]>0: # correspond a la partie positive de l'axe des y
            return [rho,pi/2]
        else:
            return [rho,-pi/2]
    elif cart[0]>0: # on peut utiliser arctangente car on est dans les x positifs
        return [rho,atan(cart[1]/cart[0])]
    elif cart[0]<0:
        return [rho,atan(cart[1]/cart[0])+pi]


######################################
# Algorithme 9:                      #
# Fonction EqDroiteOrth              #
######################################

def EqDroiteOrth(A,n): # en faisant le calcul sur une feuille, on obtient c=xA*xn+yA*yn
    return [n[0],n[1],A[0]*n[0]+A[1]*n[1]]
    

######################################
# Algorithme 10:                     #
# Fonction EqDroiteCol               #
######################################

def EqDroiteCol(A,u):
    # on calcule d'abord un vecteur normal
    n=[-u[1],u[0]]
    return EqDroiteOrth(A,n)


######################################
# Algorithme 11:                     #
# Fonction Barycentre                #
######################################

S1 = [[[0,0],1],[[4,4],1]]
S2 = [[[0,0],1],[[4,4],1],[[-2,2],2]]
def Barycentre(S):
    # on commence par calculer le poids total
    poidstotal=sum([i[1] for i in S]) # on fait la somme des seconds elements de chaque element de S.
    if poidstotal==0:
        # systeme mal defini
        return "systeme mal defini"
    else:
        # on fait la somme des alpha_i x_i divisee par le poids total et la somme  des alpha_i * y_i divisee par le poids total et on renvoie le resultat sous forme de liste
        return [sum([i[0][0]*i[1] for i in S])/poidstotal,sum([i[0][1]*i[1] for i in S])/poidstotal]
        

######################################
# Algorithme 12:                     #
# Algorithme bonus                   #
######################################

print("Nombre de points dans le disque: " + str(len([(x,y) for x  in range(-100,101) for y in range(-100,101) if Norm([x,y])<=100])))
